@@ -5,7 +5,9 @@ SUFFIXES = set([
     'esq',
     'esquire',
     'jr',
+    'jnr',
     'sr',
+    'snr',
     '2',
     'i',
     'ii',
@@ -19,6 +21,10 @@ SUFFIXES = set([
     'phd',
     'mp',
     'qc',
+    'do',
+    'dds',
+    'dpm',
+    'dmd',
 ])
 """
 
