@@ -48,15 +48,20 @@ class HumanName(object):
     """
     
     has_own_config = False
-    """True if this instance is not using the shared module-level configuration."""
+    """True if this instance is not using the shared module-level configuration. Read only."""
     
     C = CONSTANTS
     """
     A reference to the configuration for this instance, which may or may not be a
-    reference to the module-wide instance at :py:mod:`~nameparser.config.CONSTANTS`.
+    reference to the shared, module-wide instance at :py:mod:`~nameparser.config.CONSTANTS`.
     See `Customizing the Parser <customize.html>`_.
     """
     
+    original = ''
+    """
+    The original string, untouched by the parser.
+    """
+    
     count = 0
     _members = ['title','first','middle','last','suffix','nickname']
     unparsable = True
@@ -73,6 +78,7 @@ class HumanName(object):
         
         self.ENCODING = encoding
         self.string_format = string_format
+        self.original = full_name
         self.full_name = full_name
     
     def __iter__(self):
@@ -115,7 +121,7 @@ class HumanName(object):
     def __unicode__(self):
         if self.string_format:
             # string_format = "{title} {first} {middle} {last} {suffix} ({nickname})"
-            return self.string_format.format(**self.as_dict())
+            return self.collapse_whitespace(self.string_format.format(**self.as_dict())).strip(', ')
         return " ".join(self)
     
     def __str__(self):
@@ -287,7 +293,10 @@ class HumanName(object):
     def full_name(self, value):
         self._full_name = value
         self.parse_full_name()
-
+    
+    def collapse_whitespace(self, string):
+        # collapse multiple spaces into single space
+        return self.C.regexes.spaces.sub(" ", string.strip())
     
     def pre_process(self):
         """
@@ -354,8 +363,7 @@ class HumanName(object):
         
         self.pre_process()
         
-        # collapse multiple spaces
-        self._full_name = self.C.regexes.spaces.sub(" ", self._full_name.strip())
+        self._full_name = self.collapse_whitespace(self._full_name)
         
         # break up full_name by commas
         parts = [x.strip() for x in self._full_name.split(",")]
@@ -413,6 +421,10 @@ class HumanName(object):
                     if not self.first:
                         self.first_list.append(piece)
                         continue
+                    if (i == len(pieces) - 2) and self.is_suffix(nxt):
+                        self.last_list.append(piece)
+                        self.suffix_list.insert(0,nxt)
+                        break
                     if not nxt:
                         self.last_list.append(piece)
                         continue
